from aiia import AIIAConfig


class aiuNNConfig(AIIAConfig):
    def __init__(
        self,
        base_config=None,
        upsample_scale: int = 2,
        upsample_mode: str = 'bilinear',
        upsample_align_corners: bool = False,
        layers=None,
        **kwargs
    ):
        # Start with a single configuration dictionary.
        config_data = {}
        if base_config is not None:
            # If base_config is an object with a to_dict method, use it.
            if hasattr(base_config, "to_dict"):
                config_data.update(base_config.to_dict())
            elif isinstance(base_config, dict):
                config_data.update(base_config)
        
        # Update with any additional keyword arguments (if needed).
        config_data.update(kwargs)
        
        # Initialize base AIIAConfig with a single merged configuration.
        super().__init__(**config_data)
        
        # Upsampler-specific parameters.
        self.upsample_scale = upsample_scale
        self.upsample_mode = upsample_mode
        self.upsample_align_corners = upsample_align_corners
        
        # Use layers from the argument or initialize an empty list.
        self.layers = layers if layers is not None else []
        
        # Add the upsample layer details only once.
        self.add_upsample_layer()

    def add_upsample_layer(self):
        upsample_layer = {
            'name': 'Upsample',
            'type': 'nn.Upsample',
            'scale_factor': self.upsample_scale,
            'mode': self.upsample_mode,
            'align_corners': self.upsample_align_corners
        }
        # Append the layer only if it isn’t already present.
        if not any(layer.get('name') == 'Upsample' for layer in self.layers):
            self.layers.append(upsample_layer)
